﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Net;
using System.Web;
using System.Web.Mvc;
using DotNetNoteMvc.Models;

namespace DotNetNoteMvc.Controllers
{
    public class DotNetNoteController : Controller
    {
        private DotNetNoteContext db = new DotNetNoteContext();

        // GET: DotNetNote
        public ActionResult Index()
        {
            //Num 필드에 대해서 역순으로 출력
            return View(db.DotNetNoteArticles.OrderByDescending(d => d.Num).ToList());
        }

        // GET: DotNetNote/Details/5
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            DotNetNoteArticle dotNetNoteArticle = db.DotNetNoteArticles.Find(id);
            if (dotNetNoteArticle == null)
            {
                return HttpNotFound();
            }
            return View(dotNetNoteArticle);
        }

        // GET: DotNetNote/Create
        public ActionResult Create()
        {
            ViewData["Title"] = "게시판 글쓰기";
            GetEncoding();
            return View();
        }

        private void GetEncoding()
        {
            SelectList encodingOptions = new SelectList(new string[] { "Text", "HTML", "Mixed" });
            ViewBag.Encoding = encodingOptions;
        }

        // POST: DotNetNote/Create
        // 초과 게시 공격으로부터 보호하려면 바인딩하려는 특정 속성을 사용하도록 설정하세요. 
        // 자세한 내용은 https://go.microsoft.com/fwlink/?LinkId=317598을(를) 참조하세요.
        [HttpPost]
        [ValidateInput(false)] //Page 지시문에 ValidateRequest="false"와 동일 기능
        [ValidateAntiForgeryToken]
        public ActionResult Create([Bind(Include = "Id,Name,PostDate,PostIp,Title,Content,Tags,Password,Email,Homepage,ReadCount,Encoding,ModifyDate,ModifyIp")] DotNetNoteArticle dotNetNoteArticle)
        {
            //사용자 정의 서버측 유효성 검사 로직을 추가
            //간단한 유효성 검사 : https://learn.microsoft.com/ko-kr/aspnet/mvc/overview/older-versions-1/models-data/performing-simple-validation-cs
            if (Request.Form["Name"].Trim().Length < 2)
            {
                //에러 출력 : 유효성 검사 실패
                ModelState.AddModelError("Name", "이름을 입력하시오.");
            }
            if (ModelState.IsValid)
            {
                //사용자로부터 입력 받는 이외의 데이터 처리
                dotNetNoteArticle.PostDate = DateTime.Now;          //작성일을 현재시간으로 초기화
                dotNetNoteArticle.PostIp = Request.UserHostAddress; //IP주소
                dotNetNoteArticle.ReadCount = 0;                    //조회수 0으로 초기화

                db.DotNetNoteArticles.Add(dotNetNoteArticle);
                db.SaveChanges(); //실제저장
                return RedirectToAction("Index");
            }

            return View(dotNetNoteArticle);
        }

        // GET: DotNetNote/Edit/5
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            DotNetNoteArticle dotNetNoteArticle = db.DotNetNoteArticles.Find(id);
            if (dotNetNoteArticle == null)
            {
                return HttpNotFound();
            }
            return View(dotNetNoteArticle);
        }

        // POST: DotNetNote/Edit/5
        // 초과 게시 공격으로부터 보호하려면 바인딩하려는 특정 속성을 사용하도록 설정하세요. 
        // 자세한 내용은 https://go.microsoft.com/fwlink/?LinkId=317598을(를) 참조하세요.
        [HttpPost]
        [ValidateAntiForgeryToken]
        public ActionResult Edit([Bind(Include = "Id,Name,PostDate,PostIp,Title,Content,Tags,Password,Email,Homepage,ReadCount,Encoding,ModifyDate,ModifyIp")] DotNetNoteArticle dotNetNoteArticle)
        {
            if (ModelState.IsValid)
            {
                db.Entry(dotNetNoteArticle).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(dotNetNoteArticle);
        }

        // GET: DotNetNote/Delete/5
        public ActionResult Delete(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            DotNetNoteArticle dotNetNoteArticle = db.DotNetNoteArticles.Find(id);
            if (dotNetNoteArticle == null)
            {
                return HttpNotFound();
            }
            return View(dotNetNoteArticle);
        }

        // POST: DotNetNote/Delete/5
        [HttpPost, ActionName("Delete")]
        [ValidateAntiForgeryToken]
        public ActionResult DeleteConfirmed(int id)
        {
            DotNetNoteArticle dotNetNoteArticle = db.DotNetNoteArticles.Find(id);
            db.DotNetNoteArticles.Remove(dotNetNoteArticle);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }
    }
}
